==> web-9.0.0.tgz: package/lib/calendar/CalendarYearView.js <==
import * as React from "react";
export default class CalendarYearView extends React.PureComponent {
    getYearArr() {
        const { curTime: { year }, selTimeObj, clickSelHandle, lastYear } = this.props;
        const selYear = selTimeObj.get("year");
        let startTime = lastYear - 10;
        return Array.from({ length: 3 }, (...args) => (args[1] + 1)).map(row => {
            const item = Array.from({ length: 3 }, (...args) => (args[1] + 1)).map(() => {
                const num = ++startTime;
                const yearToday = year === num && "calendar-today" || "";
                const yearsel = selYear === num && "calendar-sel" || "";
                const className = "view-item " + yearToday + " " + yearsel;
                return (React.createElement("li", { "data-num": num, key: num, "data-sign": "year", className: className, onClick: (!yearsel && clickSelHandle) || undefined },
                    React.createElement("span", { className: "year-span" }, num)));
            });
            return (React.createElement("ul", { className: "year-group", key: row }, item));
        });
    }
    render() {
        const { curTime: { year }, selTimeObj, clickSelHandle, lastYear } = this.props;
        const selYear = selTimeObj.get("year");
        const yearToday = year === lastYear ? " calendar-today" : "";
        const yearsel = selYear === lastYear ? " calendar-sel" : "";
        return (React.createElement("div", { className: "m-yearView item-calendar-view" },
            this.getYearArr(),
            React.createElement("div", { "data-num": lastYear, "data-sign": "year", onClick: clickSelHandle, className: "last-year view-item " + yearToday + yearsel },
                React.createElement("span", { className: "year-span" }, lastYear))));
    }
}

==> web-11.0.2.tgz: package/lib/calendar/CalendarYearView.js <==
import * as React from "react";
export default class CalendarYearView extends React.PureComponent {
    getYearArr() {
        const { curTime: { year }, selTimeObj, clickSelHandle, lastYear } = this.props;
        const selYear = selTimeObj.get("year");
        let startTime = lastYear - 10;
        return Array.from({ length: 3 }, (...args) => (args[1] + 1)).map((row) => {
            const item = Array.from({ length: 3 }, (...args) => (args[1] + 1)).map(() => {
                const num = ++startTime;
                const yearToday = year === num && "calendar-today" || "";
                const yearsel = selYear === num && "calendar-sel" || "";
                const className = "view-item " + yearToday + " " + yearsel;
                return (React.createElement("li", { "data-num": num, key: num, "data-sign": "year", className: className, onClick: (!yearsel && clickSelHandle) || undefined },
                    React.createElement("span", { className: "year-span" }, num)));
            });
            return (React.createElement("ul", { className: "year-group", key: row }, item));
        });
    }
    render() {
        const { curTime: { year }, selTimeObj, clickSelHandle, lastYear } = this.props;
        const selYear = selTimeObj.get("year");
        const yearToday = year === lastYear ? " calendar-today" : "";
        const yearsel = selYear === lastYear ? " calendar-sel" : "";
        return (React.createElement("div", { className: "m-yearView item-calendar-view" },
            this.getYearArr(),
            React.createElement("div", { "data-num": lastYear, "data-sign": "year", onClick: clickSelHandle, className: "last-year view-item " + yearToday + yearsel },
                React.createElement("span", { className: "year-span" }, lastYear))));
    }
}
